@@ -323,7 +323,10 @@ def do_louvain_merger(in_mat, sample_k_lists, cutoff = 0):
                 cut_counter +=1
     print('cut',cut_counter,'low weight edges')
     ## make the fully connected, weighted matrix
-    G = nx.from_numpy_matrix(in_mat)
+    try:
+        G = nx.from_numpy_matrix(in_mat)
+    except:
+        G = nx.from_numpy_array(in_mat)
     for node in G.nodes():
         print(node)
     for edge in G.edges():
