@@ -573,7 +573,7 @@ def analyze_group_differences(meta_ome,
     ## do all of the analyses
     per_ome_directories = []
     all_omes = meta_ome.cat_omes_full + test_cat + meta_ome.num_omes_full + test_num
-    ome_type_annotations = ["clustering"]*len(meta_ome.cat_omes_full) + ["test"] * len(test_cat) + ["clustering"] * len(meta_ome.num_omes_full) + ["test"]
+    ome_type_annotations = ["clustering"]*len(meta_ome.cat_omes_full) + ["test"] * len(test_cat) + ["clustering"] * len(meta_ome.num_omes_full) + ["test"] * len(test_num)
     all_clustering_ome_consensus_list_of_list_dict = {}
     censensus_out_annotations_dict = {}
     for i in range(len(all_omes)):
@@ -589,6 +589,7 @@ def analyze_group_differences(meta_ome,
         ## find the consensus types
         ome_group_probs = get_within_ome_similarity(temp_sample_k_lists, ome, temp_out_dir)
         consensus_group_labels, consensus_out_list, consensus_list_of_lists = get_ome_consensus_types(ome_group_probs, temp_sample_k_lists, ome.subjects, temp_out_dir, one_hot = one_hot)
+        print(ome_type_annotations)
         if ome_type_annotations[i] == "clustering":
             all_clustering_ome_consensus_list_of_list_dict[ome.name] = consensus_list_of_lists
             censensus_out_annotations_dict[ome.name] = consensus_out_list
