@@ -71,7 +71,10 @@ def do_louvain_clust(am, mask_cutoff):
     am /= np.max(am)
     print(am)
     ## make the graph
-    G = nx.from_numpy_matrix(am)
+    try:
+        G = nx.from_numpy_matrix(am)
+    except:
+        G = nx.from_numpy_array(am)
     ## louvain modularity
     partition = community.best_partition(G)
     ## make the output labels
@@ -121,7 +124,11 @@ def do_ap_merger(am, labels):
         for j in range(0,len(final_sample_k_lists)):
             if i in final_sample_k_lists[j]:
                 final_labels.append(j)
-    return(final_labels)
+    ## finally, as a sanity check, we'll make sure that the labels are zero indexed
+    all_final_labels_list = sorted(list(set(final_labels)))
+    all_final_labels_lookup = {val:key for key, val in enumerate(all_final_labels_list)}
+    final_final_labels = [all_final_labels_lookup[i] for i in final_labels]
+    return(final_final_labels)
 
 
 def do_clust(meta_ome, am = None, full = False):
